// This scripted CopperCube action sets a custom cursor in the WebGL target. It uses the CSS cursor API described at
// https://developer.mozilla.org/en-US/docs/Web/CSS/cursor
//
// 'CursorVisible' sets whether to show or hide the cursor.
// 'CursorCSSKeyword' contains a CSS keyword to use, such as 'crosshair' or 'grabbing'.
// 'CursorUseBitmap' sets whether to use a custom bitmap for the cursor.
// 'CursorBitmap' selects a texture file to use as the cursor if 'CursorUseBitmap' is enabled.
//
// You can set any CopperCube texture as the cursor, but at the moment this only works in Firefox and Chrome.
// Internet Explorer requires cursor bitmaps to be in CUR format, which CopperCube cannot import.
// However to support IE you can hack the extension to import a CUR file from an URL.
// For custom mouseover cursors, use this action with 'Behaviours > Behaviours triggered by events > When cursor moved over do something'
//
/*
    <action jsname="action_SetCursorWebGL" description="Set custom cursor in WebGL">
        <property name="CursorVisible" type="bool" default="true" />
        <property name="CursorCSSKeyword" type="string" default="auto" />
        <property name="UseCustomBitmap" type="bool" default="false" />
        <property name="CustomBitmap" type="texture" />
        <property name="BitmapHotspotOffsetX" type="integer" default="0" />
        <property name="BitmapHotspotOffsetY" type="integer" default="0" />
    </action>
*/

action_SetCursorWebGL = function () {
    "use strict";
    this.canvas = document.querySelectorAll("canvas")[0];    // Get and remember the canvas (or our best guess!)
};

// called when the action is executed 
action_SetCursorWebGL.prototype.execute = function () {
    "use strict";
    var cursorCSSValue,
        cursorFallback;
    if (!this.CursorVisible) {
        cursorCSSValue = "none";    // User has asked to hide the cursor...
    } else if (!this.UseCustomBitmap) {
        cursorCSSValue = this.CursorCSSKeyword;    // Or, user wants a custom cursor from a CSS keyword...
    } else {
        cursorFallback = this.CursorCSSKeyword || "auto";    // Or, user wants a custom cursor from a bitmap.
        cursorCSSValue = "url(" + this.CustomBitmap + ") " +
            this.BitmapHotspotOffsetX + " " + this.BitmapHotspotOffsetY + ", " + cursorFallback;
    }
    this.canvas.style.cursor = cursorCSSValue;    // Set the cursor.
};